@@ -196,8 +196,10 @@ background-color: #808080;
                         hr(),
                         radioButtons('ccMode', label = NULL, choices = c('Markers', 'Lines+Markers')),
                         hr(),
-                        checkboxGroupInput('ccBand', label = NULL, choices = c(Red='R', Green='G', Blue='B'),
-                                           selected = c( 'G'), width = '100%', inline = F),
+                        checkboxGroupInput('ccBand', label = NULL, choices = c('RCC', 'GCC', 'BCC'),
+                                                                               # 'grR', 'rbR', 'gbR',
+                                                                               # 'GRVI', 'exG'),
+                                           selected = c('G'), width = '100%', inline = F),
                         hr(),
                         radioButtons('ccVar', label = 'Confidence Interval', choices = c('None', '50%', '80%', '90%')),
                         hr(),
